@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright 2001-2023 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -20,12 +20,16 @@ package plugin
 import (
 	"context"
 	"net/http"
+	"net/url"
 	"time"
 
+	"git.zabbix.com/ap/plugin-support/tlsconfig"
+	"git.zabbix.com/ap/plugin-support/uri"
+	"git.zabbix.com/ap/plugin-support/zbxerr"
+
 	"github.com/omeid/go-yarn"
-	"golang.zabbix.com/sdk/metric"
-	"golang.zabbix.com/sdk/plugin"
-	"golang.zabbix.com/sdk/zbxerr"
+
+	"git.zabbix.com/ap/plugin-support/plugin"
 )
 
 const (
@@ -45,18 +49,21 @@ type Plugin struct {
 var Impl Plugin
 
 // Export implements the Exporter interface.
-func (p *Plugin) Export(key string, rawParams []string, _ plugin.ContextProvider) (result any, err error) {
-	params, extraParams, hc, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
+func (p *Plugin) Export(key string, rawParams []string, _ plugin.ContextProvider) (result interface{}, err error) {
+	params, extraParams, err := metrics[key].EvalParams(rawParams, p.options.Sessions)
 	if err != nil {
 		return nil, err
 	}
 
-	err = metric.SetDefaults(params, hc, p.options.Default)
+	details, err := tlsconfig.CreateDetails(params["sessionName"], params["TLSConnect"],
+		params["TLSCAFile"], params["TLSCertFile"], params["TLSKeyFile"], params["URI"])
 	if err != nil {
-		return nil, err
+		return nil, zbxerr.ErrorInvalidConfiguration.Wrap(err)
 	}
 
-	connID, err := createConnID(params)
+	dbname := url.QueryEscape(params["Database"])
+
+	uri, err := uri.NewWithCreds(params["URI"]+"?dbname="+dbname, params["User"], params["Password"], uriDefaults)
 	if err != nil {
 		return nil, err
 	}
@@ -66,7 +73,7 @@ func (p *Plugin) Export(key string, rawParams []string, _ plugin.ContextProvider
 		return nil, zbxerr.ErrorUnsupportedMetric
 	}
 
-	conn, err := p.connMgr.GetConnection(connID, params)
+	conn, err := p.connMgr.GetConnection(*uri, details)
 	if err != nil {
 		// Special logic of processing connection errors should be used if pgsql.ping is requested
 		// because it must return pingFailed if any error occurred.
@@ -93,22 +100,30 @@ func (p *Plugin) Export(key string, rawParams []string, _ plugin.ContextProvider
 
 // Start implements the Runner interface and performs initialization when plugin is activated.
 func (p *Plugin) Start() {
-	queryStorage, err := yarn.New(http.Dir(p.options.CustomQueriesPath), "*"+sqlExt)
-	if err != nil {
-		p.Errf(err.Error())
-		// create empty storage if error occurred
-		queryStorage = yarn.NewFromMap(map[string]string{})
-	}
-
 	p.connMgr = NewConnManager(
 		time.Duration(p.options.KeepAlive)*time.Second,
 		time.Duration(p.options.Timeout)*time.Second,
 		time.Duration(p.options.CallTimeout)*time.Second,
 		hkInterval*time.Second,
-		queryStorage,
+		p.setCustomQuery(),
 	)
 }
 
+func (p *Plugin) setCustomQuery() yarn.Yarn {
+	if p.options.CustomQueriesPath == "" {
+		return yarn.NewFromMap(map[string]string{})
+	}
+
+	queryStorage, err := yarn.New(http.Dir(p.options.CustomQueriesPath), "*"+sqlExt)
+	if err != nil {
+		p.Errf(err.Error())
+		// create empty storage if error occurred
+		return yarn.NewFromMap(map[string]string{})
+	}
+
+	return queryStorage
+}
+
 // Stop implements the Runner interface and frees resources when plugin is deactivated.
 func (p *Plugin) Stop() {
 	p.connMgr.Destroy()
